Introduction
============

The ``debops.libvirtd_qemu`` role manages the QEMU configuration used by the
libvirt daemon. It is a part of the :ref:`debops.libvirtd`, separated to
allow easier configuration maintenance.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.2.3``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.libvirtd_qemu

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
